pub enum Clause {
All(Vec<Requirement>),
Between(Box<Version>, Box<Version>),
Only(Requirement),
}Expand description
A single clause within a version range.
Variants
All(Vec<Requirement>)
A list of requirements that must all match, for example >=1.2 && <2.
Between(Box<Version>, Box<Version>)
A bounded range between two fully qualified versions, inclusive
on both ends, for example 1.2.3 - 2.3.4. The versions are boxed
to keep the size of this enum down.
Only(Requirement)
A single requirement.
Implementations