A version requirement composed of a comparison operator and a full
or partial version to match against. Build metadata is accepted
when parsing, but is otherwise ignored.
Returns true if the provided value looks like a calendar version string,
instead of a semantic version string. This is used to determine which parser to use.
Returns true if the provided value looks like a semver version string,
instead of a calendar version string. This is used to determine which parser to use.